/****************************************************************************
*   COPYRIGHT 2017 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#ifndef __APPLICATION_H__
#define __APPLICATION_H__

#include "types.h"

/*! format string for printing a bd address */
#ifndef BD_ADDR_FORMAT
#define BD_ADDR_FORMAT "%02x:%02x:%02x:%02x:%02x:%02x"
#endif

/*! argument list for printing a bd_address */
#ifndef BD_ADDR_ARG
#define BD_ADDR_ARG(x) x[0], x[1], x[2], x[3], x[4], x[5]
#endif

#define MAX_BUF_SIZE 1024
extern uint8_t buf[MAX_BUF_SIZE];

int application_init(const char *device_name);
int application_process(void);
void application_shutdown(void);
int application_handle_keyboard_input(int key);
int application_handle_at_event(uint8_t *ascii, int ascii_length, uint8_t *binary, int binary_length);

#define COMMA ','
#define END '\r', '\n'

int at_send_command(const uint8_t *cmd, unsigned int len);
int at_receive_line(uint8_t *buf, unsigned int max_length, unsigned int *length, int timeout);

int send_at_lediscon(uint8_t *bd_address);

#define RING_SIZE 64
typedef uint32_t ring_pos_t;
struct rb {
	volatile ring_pos_t ring_head;
	volatile ring_pos_t ring_tail;
	volatile uint8_t ring_data[RING_SIZE];
};

void flush_rb(struct rb *rb);
int add_to_rb(struct rb *rb, uint8_t c);
int remove_from_rb(struct rb *rb, uint8_t *c);

/* For PAN1760A */
#define SER_ATT_MTU_SIZE_MAX 160

struct config
{
	uint8_t buf2[SER_ATT_MTU_SIZE_MAX];
	uint16_t mtu_size;
	bool is_connected;
	uint16_t connection_id;
	bool is_indication_enabled;
	bool is_sending;
	uint8_t bd_address[6];
	struct rb in;
};

extern struct config config;

#ifdef DEBUG
#define dprintf(...) do { printf("[%d|%d|%d] %s(): ", config.is_connected, config.is_indication_enabled, config.mtu_size ,__func__); printf(__VA_ARGS__); } while(0)
#else
#define dprintf(...)
#endif

#define warning(...) do { printf("[%d|%d|%d] %s(): ", config.is_connected, config.is_indication_enabled, config.mtu_size ,__func__); printf(__VA_ARGS__); } while(0)

#endif