/****************************************************************************
*   COPYRIGHT 2017 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#ifndef __NFC_SETTING_H__
#define __NFC_SETTING_H__

/*******************************************************************************
  DEBUG enable/disable
*******************************************************************************/
/* #define TSB_NFC_DEBUG */

/*******************************************************************************
  Definition depends on the LSI
*******************************************************************************/
#include "nfc_TC35670.h"

/*******************************************************************************
  Wired I/F define
*******************************************************************************/
#define TSB_NFC_WIRED_IF_I2C
#undef TSB_NFC_WIRED_IF_UART
#undef TSB_NFC_WIRED_IF_SPI

/*******************************************************************************
  for High Level API
*******************************************************************************/
/*---------------------------------------------------------------*/
/* critical section disable/enable in TsbNfcTagLsiPowerSyncRfdet */
/*---------------------------------------------------------------*/
#define ENABLE_TSBNFCTAGLSIPOWERSYNCRFDET_CRIT

/*---------------------------------------------------------------*/
/* powerof timer disable/enable in TsbNfcTagLsiPowerSyncRfdet */
/*---------------------------------------------------------------*/
#undef DISABLE_POWERSYNCRFDET_TIMER

/*-------------------*/
/* Reset wait define */
/*-------------------*/
#define NFC_WAIT_TIME_AFTER_POWEROFF 1   /* 1ms */
#define NFC_WAIT_TIME_BEFORE_POWEROFF 17 /* 17ms */

/*-------------------*/
/* Power On Timout   */
/*-------------------*/
#define TSB_USER_POWERON_TIMEOUT_MS (10 * 1000)  /* 10s */
#define TSB_RFDET_POWERON_TIMEOUT_MS (60 * 1000) /* 60s */

/*******************************************************************************
  for Software
*******************************************************************************/
#define WAIT_TIME_AFTER_POWERON 5 /* 5ms */

/*-----------------*/
/* Anti-Broken     */
/*-----------------*/
#define TSB_NFC_ANTI_BROKEN_BLOCKS 4
#define TSB_NFC_ANTI_WRITE_FLAG_BLOCK(n) (n + TSB_NFC_ANTI_BROKEN_BLOCKS * 2 - 2)

/*******************************************************************************
  for Low Level API
*******************************************************************************/
/*-------------------------------------*/
/*  sync code (slave address only I2C) */
/*-------------------------------------*/
#ifdef TSB_NFC_WIRED_IF_I2C
#define TSB_CODE_SYNC 0x60
#elif defined(TSB_NFC_WIRED_IF_UART)
#define TSB_CODE_SYNC 0x80
#elif defined(TSB_NFC_WIRED_IF_SPI)
#define TSB_CODE_SYNC 0x80
#endif

/*----------------------*/
/*  retry param define  */
/*----------------------*/
#define TSB_RETRY_WAIT_TIME 1             /* 1ms */
#define TSB_RETRY_TIMEOUT_TIME (3 * 1000) /* 3sec */

/*******************************************************************************
  Function enable/disable
*******************************************************************************/
/* unnecessary function, change from #define to #undef */
#define ENABLE_NFC_HIGH_LEVEL_API
/*------------------*/
/*  nfc_hi_api      */
/*------------------*/
#ifdef ENABLE_NFC_HIGH_LEVEL_API
#define ENABLE_FNC_TSBNFCINIT                        //TsbNfcInit
#define ENABLE_FNC_TSBNFCDEINIT                      //TsbNfcDeinit
#define ENABLE_FNC_TSBNFCBLOCKREAD                   //TsbNfcBlockRead
#define ENABLE_FNC_TSBNFCBLOCKWRITE                  //TsbNfcBlockWrite
#define ENABLE_FNC_TSBNFCSPADREADANTIBROKEN          //TsbNfcSpadReadAntiBroken
#define ENABLE_FNC_TSBNFCSPADWRITEANTIBROKEN         //TsbNfcSpadWriteAntiBroken
#define ENABLE_FNC_TSBNFCSPADREAD                    //TsbNfcSpadRead
#define ENABLE_FNC_TSBNFCSPADWRITE                   //TsbNfcSpadWrite
#define ENABLE_FNC_TSBNFCSPADREADMAC                 //TsbNfcSpadReadMac
#define ENABLE_FNC_TSBNFCSPADWRITEMAC                //TsbNfcSpadWriteMac
#define ENABLE_FNC_TSBNFCCARDKEYVERSIONWRITEMAC      //TsbNfcCardKeyVersionWriteMac
#define ENABLE_FNC_TSBNFCCARDKEYWRITEMAC             //TsbNfcCardKeyWriteMac
#define ENABLE_FNC_TSBNFCSPADREADAUTH                //TsbNfcSpadReadAuth
#define ENABLE_FNC_TSBNFCSPADWRITEAUTH               //TsbNfcSpadWriteAuth
#define ENABLE_FNC_TSBNFCTHROUGHMODEGETLENGTH        //TsbNfcThroughModeGetLength
#define ENABLE_FNC_TSBNFCTHROUGHMODEREAD             //TsbNfcThroughModeRead
#define ENABLE_FNC_TSBNFCTHROUGHMODEWRITE            //TsbNfcThroughModeWrite
#define ENABLE_FNC_TSBNFCSETWIRELESSSPADWRITEPROTECT //TsbNfcSetWirelessSpadWriteProtect
#define ENABLE_FNC_TSBNFCGETWIRELESSSPADWRITEPROTECT //TsbNfcGetWirelessSpadWriteProtect
#define ENABLE_FNC_TSBNFCSETMEMORYCONFIGWRITEPROTECT //TsbNfcSetMemoryConfigWriteProtect
#define ENABLE_FNC_TSBNFCGETMEMORYCONFIGWRITEPROTECT //TsbNfcGetMemoryConfigWriteProtect
#define ENABLE_FNC_TSBNFCSETSYSTEMCONFIGWRITEPROTECT //TsbNfcSetSystemConfigWriteProtect
#define ENABLE_FNC_TSBNFCGETSYSTEMCONFIGWRITEPROTECT //TsbNfcGetSystemConfigWriteProtect
#define ENABLE_FNC_TSBNFCSETNDEFRESPONSE             //TsbNfcSetNdefResponse
#define ENABLE_FNC_TSBNFCGETNDEFRESPONSE             //TsbNfcGetNdefResponse
#define ENABLE_FNC_TSBNFCSETCARDKEYWRITEPROTECT      //TsbNfcSetCardKeyWriteProtect
#define ENABLE_FNC_TSBNFCGETCARDKEYWRITEPROTECT      //TsbNfcGetCardKeyWriteProtect
#define ENABLE_FNC_TSBNFCSETSPADREADAUTHENTICATION   //TsbNfcSetSpadReadAuthentication
#define ENABLE_FNC_TSBNFCGETSPADREADAUTHENTICATION   //TsbNfcGetSpadReadAuthentication
#define ENABLE_FNC_TSBNFCSETSPADWRITEAUTHENTICATION  //TsbNfcSetSpadWriteAuthentication
#define ENABLE_FNC_TSBNFCGETSPADWRITEAUTHENTICATION  //TsbNfcGetSpadWriteAuthentication
#define ENABLE_FNC_TSBNFCSETSPADWRITEMAC             //TsbNfcSetSpadWriteMac
#define ENABLE_FNC_TSBNFCGETSPADWRITEMAC             //TsbNfcGetSpadWriteMac
#define ENABLE_FNC_TSBNFCSETSTATEWRITEMAC            //TsbNfcSetStateWriteMac
#define ENABLE_FNC_TSBNFCGETSTATEWRITEMAC            //TsbNfcGetStateWriteMac
#define ENABLE_FNC_TSBNFCSETRFPARAM                  //TsbNfcSetRfParam
#define ENABLE_FNC_TSBNFCGETRFPARAM                  //TsbNfcGetRfParam
#define ENABLE_FNC_TSBNFCSETREGBLOCK                 //TsbNfcSetRegBlock
#define ENABLE_FNC_TSBNFCGETREGBLOCK                 //TsbNfcGetRegBlock
#define ENABLE_FNC_TSBNFCSETTHROUGHMODEDISABLE       //TsbNfcSetThroughModeDisable
#define ENABLE_FNC_TSBNFCGETTHROUGHMODEDISABLE       //TsbNfcGetThroughModeDisable
#define ENABLE_FNC_TSBNFCSETUARTTIMEOUT              //TsbNfcSetUartTimeout
#define ENABLE_FNC_TSBNFCGETUARTTIMEOUT              //TsbNfcGetUartTimeout
#define ENABLE_FNC_TSBNFCSETI2CSLAVEADDR             //TsbNfcSetI2cSlaveAddr
#define ENABLE_FNC_TSBNFCGETI2CSLAVEADDR             //TsbNfcGetI2cSlaveAddr
#define ENABLE_FNC_TSBNFCSETWIREDIFMODE              //TsbNfcSetWiredIfMode
#define ENABLE_FNC_TSBNFCGETWIREDIFMODE              //TsbNfcGetWiredIfMode
#define ENABLE_FNC_TSBNFCSETWIREDIFMODEENABLE        //TsbNfcSetWiredIfModeEnable
#define ENABLE_FNC_TSBNFCGETWIREDIFMODEENABLE        //TsbNfcGetWiredIfModeEnable
#define ENABLE_FNC_TSBNFCSETWIREDSPADWRITEPROTECT    //TsbNfcSetWiredSpadWriteProtect
#define ENABLE_FNC_TSBNFCGETWIREDSPADWRITEPROTECT    //TsbNfcGetWiredSpadWriteProtect
#define ENABLE_FNC_TSBNFCSETWIRELESSSPADREADPROTECT  //TsbNfcSetWirelessSpadReadProtect
#define ENABLE_FNC_TSBNFCGETWIRELESSSPADREADPROTECT  //TsbNfcGetWirelessSpadReadProtect
#define ENABLE_FNC_TSBNFCTAGLSIPOWER                 //TsbNfcTagLsiPower
#define ENABLE_FNC_TSBNFCTAGLSIPOWERSYNCRFDET        //TsbNfcTagLsiPowerSyncRfdet
#define ENABLE_FNC_TSBNFCGETDEBUGSTATUSFLAG          //TsbNfcGetDebugStatusFlag
#define ENABLE_FNC_TSBNFCSETUSERPOWERONTIMEOUT       //TsbNfcSetUserPowerOnTimeout
#define ENABLE_FNC_TSBNFCGETUSERPOWERONTIMEOUT       //TsbNfcGetUserPowerOnTimeout
#define ENABLE_FNC_TSBNFCSETRFDETPOWERONTIMEOUT      //TsbNfcSetRfdetPowerOnTimeout
#define ENABLE_FNC_TSBNFCGETRFDETPOWERONTIMEOUT      //TsbNfcGetRfdetPowerOnTimeout
/* static functions */
#define ENABLE_FNC_TSBNFCCHKRET     //TsbNfcChkret
#define ENABLE_FNC_TSBNFCFORCERESET //TsbNfcForceReset
#endif                              /* ENABLE_NFC_HIGH_LEVEL_API */

/*------------------*/
/*  nfc_proc        */
/*------------------*/
/* The nfc_proc's APIs except the following APIs synchronize with nfc_hi_api. */
/*   ENABLE_FNC_TSBSNFCBLOCKREAD             */
/*   ENABLE_FNC_TSBSNFCBLOCKWRITE            */
/*   ENABLE_FNC_TSBSNFCPOWERCTL              */
/*   ENABLE_FNC_TSBSNFCWIRELESSACCESSPROTECT */
#if defined(ENABLE_FNC_TSBNFCINIT)
#define ENABLE_FNC_TSBSNFCINIT //TsbSNfcInit
#endif
#if defined(ENABLE_FNC_TSBNFCDEINIT)
#define ENABLE_FNC_TSBSNFCDEINIT //TsbSNfcDeinit
#endif

#define ENABLE_FNC_TSBSNFCBLOCKREAD  //TsbSNfcBlockRead
#define ENABLE_FNC_TSBSNFCBLOCKWRITE //TsbSNfcBlockWrite

#if defined(ENABLE_FNC_TSBNFCTHROUGHMODEGETLENGTH)
#define ENABLE_FNC_TSBSNFCGETLENGTH //TsbSNfcGetLength
#endif
#if defined(ENABLE_FNC_TSBNFCTHROUGHMODEREAD)
#define ENABLE_FNC_TSBSNFCTMREAD //TsbSNfcTMRead
#endif
#if defined(ENABLE_FNC_TSBNFCTHROUGHMODEWRITE)
#define ENABLE_FNC_TSBSNFCTMWRITE //TsbSNfcTMWrite
#endif
#if defined(ENABLE_FNC_TSBNFCSPADREADMAC) || defined(ENABLE_FNC_TSBNFCSPADWRITEMAC) || defined(ENABLE_FNC_TSBNFCSPADREADAUTH) || \
    defined(ENABLE_FNC_TSBNFCSPADWRITEAUTH) || defined(ENABLE_FNC_TSBNFCCARDKEYVERSIONWRITEMAC) || defined(ENABLE_FNC_TSBNFCCARDKEYWRITEMAC)
#define ENABLE_FNC_TSBSNFCINTERAUTH //TsbSNfcInterAuth
#endif
#if defined(ENABLE_FNC_TSBNFCSPADREADAUTH) || defined(ENABLE_FNC_TSBNFCSPADWRITEAUTH)
#define ENABLE_FNC_TSBSNFCEXTERAUTH //TsbSNfcExterAuth
#endif

#define ENABLE_FNC_TSBSNFCPOWERCTL //TsbSNfcPowerCtl

#if defined(ENABLE_FNC_TSBSNFCBLOCKREAD) || defined(ENABLE_FNC_TSBSNFCBLOCKWRITE)
#define ENABLE_FNC_TSBSNFCSETSTATUSFLAG //TsbSNfcSetStatusFlag
#endif
#if defined(ENABLE_FNC_TSBSNFCPOWERCTL) || defined(ENABLE_FNC_TSBSNFCINIT)
#define ENABLE_FNC_TSBSNFCCLEARSTATUSFLAG //TsbSNfcClearStatusFlag
#endif
#if defined(ENABLE_FNC_TSBNFCGETDEBUGSTATUSFLAG)
#define ENABLE_FNC_TSBSNFCGETSTATUSFLAG //TsbSNfcGetStatusFlag
#endif
#if defined(ENABLE_FNC_TSBNFCSETUSERPOWERONTIMEOUT)
#define ENABLE_FNC_TSBSNFCSETUSERPOWERONTIMEOUT //TsbSNfcSetUserPowerOnTimeout
#endif
#if defined(ENABLE_FNC_TSBNFCGETUSERPOWERONTIMEOUT)
#define ENABLE_FNC_TSBSNFCGETUSERPOWERONTIMEOUT //TsbSNfcGetUserPowerOnTimeout
#endif
#if defined(ENABLE_FNC_TSBNFCSETRFDETPOWERONTIMEOUT)
#define ENABLE_FNC_TSBSNFCSETRFDETPOWERONTIMEOUT //TsbSNfcSetRfdetPowerOnTimeout
#endif
#if defined(ENABLE_FNC_TSBNFCGETRFDETPOWERONTIMEOUT)
#define ENABLE_FNC_TSBSNFCGETRFDETPOWERONTIMEOUT //TsbSNfcGetRfdetPowerOnTimeout
#endif

#define ENABLE_FNC_TSBSNFCWIRELESSACCESSPROTECT //TsbSNfcWirelessAccessProtect

#if defined(ENABLE_FNC_TSBNFCSPADREADMAC) || defined(ENABLE_FNC_TSBSNFCINTERAUTH)
#define ENABLE_FNC_TSBSNFCGENREADMAC //TsbSNfcGenReadMAC
#endif
#if defined(ENABLE_FNC_TSBSNFCEXTERAUTH) || defined(ENABLE_FNC_TSBNFCSPADWRITEMAC) || \
    defined(ENABLE_FNC_TSBNFCCARDKEYVERSIONWRITEMAC) || defined(ENABLE_FNC_TSBNFCCARDKEYWRITEMAC)
#define ENABLE_FNC_TSBSNFCGENWRITEMAC //TsbSNfcGenWriteMAC
#endif
/* static functions */
#if defined(ENABLE_FNC_TSBSNFCBLOCKREAD) || defined(ENABLE_FNC_TSBSNFCBLOCKWRITE)
#define ENABLE_FNC_NFCPROCSFTOERR //NfcProcSFtoERR
#endif
#if defined(ENABLE_FNC_TSBSNFCINTERAUTH)
#define ENABLE_FNC_NFCPROCGENSESKEY //NfcProcGenSesKey
#endif
#if defined(ENABLE_FNC_NFCPROCGENSESKEY) || defined(ENABLE_FNC_TSBSNFCGENREADMAC) || defined(ENABLE_FNC_TSBSNFCGENWRITEMAC)
#define ENABLE_FNC_NFCPROCREVERSEORDER //NfcProcReverseOrder
#endif
#if defined(ENABLE_FNC_TSBSNFCINTERAUTH)
#define ENABLE_FNC_NFCPROCGENCARDKEY //NfcProcGenCardKey
#endif
#if defined(ENABLE_FNC_TSBSNFCBLOCKREAD) || defined(ENABLE_FNC_TSBSNFCBLOCKWRITE) || defined(ENABLE_FNC_TSBSNFCGETLENGTH)
#define ENABLE_FNC_NFCPROCGETSTATUS //NfcProcGetStatus
#endif
#if defined(ENABLE_FNC_TSBSNFCBLOCKREAD) || defined(ENABLE_FNC_TSBSNFCBLOCKWRITE) || defined(ENABLE_FNC_TSBSNFCGETLENGTH)
#define ENABLE_FNC_NFCPROCGETLENGTH //NfcProcGetLength
#endif
#if defined(ENABLE_FNC_TSBSNFCBLOCKREAD) || defined(ENABLE_FNC_TSBSNFCBLOCKWRITE)
#define ENABLE_FNC_NFCPROCGETRESPONSE //NfcProcGetResponse
#endif

/* DES Cipher */
#if defined(ENABLE_FNC_NFCPROCGENSESKEY) || defined(ENABLE_FNC_TSBSNFCGENREADMAC) || defined(ENABLE_FNC_TSBSNFCGENWRITEMAC)
#define ENABLE_FNC_NFCPROC3DESINIT
#define ENABLE_FNC_NFCPROC3DESCIPHERCBC
#endif

/*------------------*/
/*  nfc_low_api     */
/*------------------*/
#define ENABLE_FNC_TSBNFCLOWSETWRITE    //TsbNfcLowSetWrite
#define ENABLE_FNC_TSBNFCLOWSETREAD     //TsbNfcLowSetRead
#define ENABLE_FNC_TSBNFCLOWGETSTATUS   //TsbNfcLowGetStatus
#define ENABLE_FNC_TSBNFCLOWGETLENGTH   //TsbNfcLowGetLength
#define ENABLE_FNC_TSBNFCLOWGETRESPONSE //TsbNfcLowGetResponse
#define ENABLE_FNC_TSBNFCLOWGETTMDATA   //TsbNfcLowGetTmData
#define ENABLE_FNC_TSBNFCLOWPUTTMDATA   //TsbNfcLowPutTmData
#define ENABLE_FNC_TSBNFCLOWPOWERON     //TsbNfcLowPowerOn
#define ENABLE_FNC_TSBNFCLOWPOWEROFF    //TsbNfcLowPowerOff
#define ENABLE_FNC_TSBNFCLOWINIT        //TsbNfcLowInit
#define ENABLE_FNC_TSBNFCLOWDEINIT      //TsbNfcLowDeinit
/* static functions */
#define ENABLE_FNC_NFCLOWCPYBLKLISTELE   //NfcLowCpyBlkListEle
#define ENABLE_FNC_NFCLOWSTR2ERRCODERW   //NfcLowStr2ErrcodeRW
#define ENABLE_FNC_NFCLOWSTR2ERRCODESTAT //NfcLowStr2ErrcodeStat
#define ENABLE_FNC_NFCLOWSTR2ERRCODELEN  //NfcLowStr2ErrcodeLen
#define ENABLE_FNC_NFCLOWSTR2ERRCODERES  //NfcLowStr2ErrcodeRes
#define ENABLE_FNC_NFCLOWSTR2ERRCODEGTM  //NfcLowStr2ErrcodeGTM
#define ENABLE_FNC_NFCLOWSTR2ERRCODEPTM  //NfcLowStr2ErrcodePTM
#define ENABLE_FNC_TSBNFCLOWCALCCHKSUM   //TsbNfcLowCalcChkSum

#endif
