/****************************************************************************
*   COPYRIGHT 2017 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

/**
* @file debug.h
*
* @brief Contains definitions and function declarations for debug handling
*/
#ifndef __DEBUG_H__
#define __DEBUG_H__

#include "types.h"
#include "application.h"
#include "version_specific.h"

#define BD_ADDR_FORMAT "%02x%02x%02x%02x%02x%02x"
#define BD_ADDR_ARG(x) x[0], x[1], x[2], x[3], x[4], x[5]

#ifndef DEBUG
/*! If DEBUG is not defined, vPrintf() is a no-op */
#define dprintf(...)
#else
/*! If DEBUG is defined, use debug functions to output information */
#define dprintf(...)                \
  do {                              \
    uart1_printf("%s(): ", __func__); \
    uart1_printf(__VA_ARGS__);        \
  } while (0)

#endif

#ifndef NDEBUG
/*! If DEBUG is defined, use debug functions to output information */
#define warning(...)                    \
  do {                                  \
    uart1_printf("[W] %s(): ", __func__); \
    uart1_printf(__VA_ARGS__);            \
  } while (0)
#else
/*! If DEBUG is not defined, warning() is a no-op */
#define warning(...)
#endif
    
/*! assert() is currently a no-op */
#define assert(...)

/*! empty default debug macro definition a no-op */
#define vPrintf(...)
#define gatt_bs_printf(...)
#define gap_bs_printf(...)
#define smp_bs_printf(...)
#define spp_bs_printf(...)
#define ven_bs_printf(...)
#define hci_bs_printf(...)
#define buff_bs_printf(...)

/*! Definition of the printf function used in the Bluetooth stack */
#define bs_printf dprintf

/*! Definition of the warning function used in the Bluetooth stack */
#define bs_warning warning

#endif
